"use strict";
/*
* This program and the accompanying materials are made available under the terms of the
* Eclipse Public License v2.0 which accompanies this distribution, and is available at
* https://www.eclipse.org/legal/epl-v20.html
*
* SPDX-License-Identifier: EPL-2.0
*
* Copyright Contributors to the Zowe Project.
*
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const utilities_1 = require("../../../../../utilities");
/**
 * The get command group handler for cli configuration settings.
 */
class ProfilesHandler {
    /**
     * Process the command and input.
     *
     * @param {IHandlerParameters} params Parameters supplied by yargs
     *
     * @throws {ImperativeError}
     */
    process(params) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = utilities_1.ImperativeConfig.instance.config;
            const paths = [];
            this.build(config.properties.profiles, "", paths);
            params.response.data.setObj(paths);
            params.response.format.output({
                format: "list",
                output: paths
            });
        });
    }
    build(profiles, path, paths) {
        const tmp = path;
        for (const [n, p] of Object.entries(profiles)) {
            const cur = tmp + `${tmp.length > 0 ? "." : ""}${n}`;
            paths.push(cur);
            if (p.profiles != null)
                this.build(p.profiles, cur, paths);
        }
    }
}
exports.default = ProfilesHandler;
//# sourceMappingURL=profiles.handler.js.map